/// <reference types="chrome" />
import { Port } from '../models/port';
import { IpcExtension } from '../models/ipc-extension';
import { IpcEvent } from '../models/ipc-event';
export declare const getAPI: (extension: IpcExtension, sessionId: number) => {
    runtime: {
        lastError: any;
        id: string;
        onConnect: import("../models/local-event").LocalEvent;
        onMessage: import("../models/local-event").LocalEvent;
        onInstalled: import("../models/local-event").LocalEvent;
        onUpdateAvailable: import("../models/local-event").LocalEvent;
        sendMessage: (...args: any[]) => void;
        connect: (...args: any[]) => Port;
        reload: () => void;
        getURL: (path: string) => string;
        getManifest: () => chrome.runtime.Manifest;
    };
    storage: {
        local: {
            set: (arg: any, cb: any) => void;
            get: (arg: any, cb: any) => void;
            remove: (arg: any, cb: any) => void;
            clear: (arg: any, cb: any) => void;
        };
        managed: {
            set: (arg: any, cb: any) => void;
            get: (arg: any, cb: any) => void;
            remove: (arg: any, cb: any) => void;
            clear: (arg: any, cb: any) => void;
        };
        sync: {
            set: (arg: any, cb: any) => void;
            get: (arg: any, cb: any) => void;
            remove: (arg: any, cb: any) => void;
            clear: (arg: any, cb: any) => void;
        };
        onChanged: {
            addListener: () => void;
        };
    };
    tabs: {
        onCreated: IpcEvent;
        onUpdated: IpcEvent;
        onActivated: IpcEvent;
        onRemoved: IpcEvent;
        get: (tabId: number, callback: (tab: chrome.tabs.Tab) => void) => void;
        getCurrent: (callback: (tab: chrome.tabs.Tab) => void) => void;
        query: (queryInfo: chrome.tabs.QueryInfo, callback: (tabs: chrome.tabs.Tab[]) => void) => Promise<void>;
        create: (createProperties: chrome.tabs.CreateProperties, callback?: (tab: chrome.tabs.Tab) => void) => void;
        insertCSS: (...args: any[]) => void;
        executeScript: (...args: any[]) => void;
        setZoom: (tabId: number, zoomFactor: number, callback: () => void) => void;
        getZoom: (tabId: number, callback: (zoomFactor: number) => void) => void;
        detectLanguage: (tabId: number, callback: (language: string) => void) => void;
        sendMessage: (...args: any[]) => void;
        update: () => void;
    };
    i18n: {
        getAcceptLanguages: (cb: any) => void;
        getMessage: (messageName: string, substitutions?: any) => any;
        getUILanguage: () => string;
        detectLanguage: (text: string, cb: any) => void;
    };
    browserAction: {
        onClicked: IpcEvent;
        setIcon: (details: chrome.browserAction.TabIconDetails, cb: any) => void;
        setBadgeBackgroundColor: (details: chrome.browserAction.BadgeBackgroundColorDetails, cb: any) => void;
        setBadgeText: (details: chrome.browserAction.BadgeTextDetails, cb: any) => Promise<void>;
    };
    webRequest: {
        ResourceType: {
            CSP_REPORT: string;
            FONT: string;
            IMAGE: string;
            MAIN_FRAME: string;
            MEDIA: string;
            OBJECT: string;
            OTHER: string;
            PING: string;
            SCRIPT: string;
            STYLESHEET: string;
            SUB_FRAME: string;
            WEBSOCKET: string;
            XMLHTTPREQUEST: string;
        };
        onBeforeRequest: import("../models/web-request-event").WebRequestEvent;
        onBeforeSendHeaders: import("../models/web-request-event").WebRequestEvent;
        onHeadersReceived: import("../models/web-request-event").WebRequestEvent;
        onSendHeaders: import("../models/web-request-event").WebRequestEvent;
        onResponseStarted: import("../models/web-request-event").WebRequestEvent;
        onBeforeRedirect: import("../models/web-request-event").WebRequestEvent;
        onCompleted: import("../models/web-request-event").WebRequestEvent;
        onErrorOccurred: import("../models/web-request-event").WebRequestEvent;
        onAuthRequired: import("../models/web-request-event").WebRequestEvent;
    };
    webNavigation: {
        onBeforeNavigate: IpcEvent;
        onCommitted: IpcEvent;
        onDOMContentLoaded: IpcEvent;
        onCompleted: IpcEvent;
        onCreatedNavigationTarget: IpcEvent;
        onReferenceFragmentUpdated: IpcEvent;
        onTabReplaced: IpcEvent;
        onHistoryStateUpdated: IpcEvent;
    };
    cookies: {
        onChanged: IpcEvent;
        get: (details: any, callback: any) => Promise<void>;
        getAll: (details: any, callback: any) => Promise<void>;
        set: (details: any, callback: any) => Promise<void>;
        remove: (details: any, callback: any) => Promise<void>;
    };
    alarms: {
        onAlarm: IpcEvent;
        create: (name: string | chrome.alarms.AlarmCreateInfo, alarmInfo: chrome.alarms.AlarmCreateInfo) => void;
        get: (name: string, cb: any) => void;
        getAll: (cb: any) => void;
        clear: (name: string, cb: any) => void;
        clearAll: (cb: any) => void;
    };
    extension: {
        isIncognitoContext: boolean;
        getURL: (path: string) => string;
        isAllowedIncognitoAccess: (cb: any) => void;
    };
    contextMenus: {
        onClicked: IpcEvent;
        create: () => void;
        removeAll: () => void;
    };
    windows: {
        get: () => void;
        onFocusChanged: IpcEvent;
    };
    management: {
        getSelf: (cb: any) => void;
        getAll: (cb: any) => void;
    };
    privacy: {
        network: {
            networkPredictionEnabled: {
                set: () => void;
                clear: () => void;
            };
            webRTCMultipleRoutesEnabled: {};
            webRTCNonProxiedUdpEnabled: {};
            webRTCIPHandlingPolicy: {};
        };
        websites: {
            hyperlinkAuditingEnabled: {
                set: () => void;
                clear: () => void;
            };
        };
    };
};
